@@ -2,7 +2,8 @@ import argparse
 import os
 
 from tasq_cli import settings
-from tasq_cli.upload import do_upload, create_csv_from_currently_uploaded_files
+from tasq_cli.upload import do_upload, create_csv_from_currently_uploaded_files, upload_csv
+from tasq_cli import jobs
 
 from django.utils.text import slugify
 
@@ -25,11 +26,28 @@ def main():
     images_parser.add_argument('-e', '--exclude', help='File extensions to exclude.', action='append', nargs='*')
     images_parser.add_argument('--dry', help='create upload file but dont actually upload anything', action='store_true')
 
-    csv_parser = subparsers.add_parser('create_csv', help='upload files')
+    csv_parser = subparsers.add_parser('create-csv', help='create csv for files that were already uploaded')
     csv_parser.add_argument('-d', '--csv-dataset-name', action='store', help='dataset name of csv to create')
     csv_parser.add_argument('-f', '--file-name', action='store', help='one file from dataset of csv to create')
     csv_parser.add_argument('--dry', help='create upload file but dont actually upload anything', action='store_true')
 
+    upload_csv_parser = subparsers.add_parser('upload-csv', help='upload files')
+    upload_csv_parser.add_argument('project_id', default=False, help='project in which to run a job')
+    upload_csv_parser.add_argument('file_name', help='csv file to upload to project')
+    upload_csv_parser.add_argument('--dry', help='run but dont actually upload anything', action='store_true')
+
+    run_job_parser = subparsers.add_parser('run-job', help='run a job')
+    run_job_parser.add_argument('project_id', default=False, help='project in which to run a job')
+    run_job_parser.add_argument('--tag', help='tag to include', action='append', nargs='*')
+    run_job_parser.add_argument('--type', help='job type: annotation/composite')
+
+    list_job_parser = subparsers.add_parser('list-jobs', help='list all jobs in a project')
+    list_job_parser.add_argument('project_id', help='the project id')
+
+    export_job_parser = subparsers.add_parser('export-job', help='exports a job')
+    export_job_parser.add_argument('job_id', help='the job id')
+    export_job_parser.add_argument('--raw', action='store_true', help='the job id')
+
     args = parser.parse_args()
     logger = settings.get_logger()
 
@@ -69,5 +87,19 @@ def main():
         settings.dry = args.dry
         do_upload(DATASET_NAME, args.path, args.exclude, settings)
 
-    if args.action == 'create_csv':
+    if args.action == 'create-csv':
         create_csv_from_currently_uploaded_files(args.csv_dataset_name, args.file_name, settings) 
+
+    if args.action == 'upload-csv':
+        upload_csv(args)
+
+    if args.action == 'run-job':
+        jobs.run_job(args)
+    if args.action == 'list-jobs':
+        jobs.list_jobs(args)
+    if args.action == 'export-job':
+        jobs.export_job(args)
+
+
+if __name__ == "__main__":
+    main()
\ No newline at end of file
