@@ -15,6 +15,7 @@ from multiprocessing.pool import ThreadPool
 
 # import settings
 from tasq_cli.db import UploadsDatabase
+from tasq_cli.server import make_request
 # from utils import timestamp_for_file_name
 
 logger = None
@@ -225,3 +226,44 @@ def get_dataset_name(db, file_name):
     relative_file_path = f'{leaf_path}{file_path.split(leaf_path)[-1]}'.replace('-', '_')
     res = db.get_dataset_name_by_filename(f'{relative_file_path}/{file_name}')
     return res
+
+
+def upload_csv(args):
+    # headers = {
+    #     'Content-Type': 'multipart/form-data; boundary=----WebKitFormBoundary0W2raMzzSKutrSDG',
+    #     'Accept': '*/*',
+    # }
+    # data = {
+    #     f"""$------WebKitFormBoundary0W2raMzzSKutrSDG\\r\\nContent-Disposition: form-data; name': '"file"; filename={file_name}\\r\\nContent-Type: text/csv\\r\\n\\r\\n\\r\\n------WebKitFormBoundary0W2raMzzSKutrSDG--\\r\\n"""
+    # }
+    file_name = os.path.basename(args.file_name)
+    multipart_form_data = {
+        'file': (file_name, open(args.file_name, 'rb')),
+        'action': (None, 'store'),
+        'path': (None, '/path1')
+    }
+    url = '/direct_uploads'
+    # headers = {'content-type': 'application/x-www-form-urlencoded'}
+    headers = {}
+    r = make_request(url, files=multipart_form_data, headers=headers)
+    generic_file_id = int(r.json()['data']['id'])
+    r = make_request(f'/projects/{args.project_id}')
+    dataset_id = r.json()['data']['attributes']['datasetId']
+    headers={'content-type': 'application/vnd.api+json', 'accept':'application/vnd.api+json'}
+
+    r = make_request('/source_files', headers=headers, json=
+        {
+            "data": {
+            "type":"source_files",
+            "attributes": {
+                "file": {
+                    "type":"GenericFile",
+                     "id": generic_file_id
+                },
+                "dataset":{
+                    "type":"dataset",
+                    "id": dataset_id
+                }
+            }
+        }})
+
